Antiland Package Documentation
==============================

.. image:: antiland_logo.png
   :align: center

Welcome to the documentation for the Antiland Python package. This package provides functionality for working with accounts, bots, dialogues, users, and messages on the Antiland platform.

Getting started
-----------------

Is this your first time using the library? This is the place to get started!

- **First steps:** :doc:`intro` | :doc:`quickstart` | 
- **Examples:** Examples are Located in the examples directory 
- https://github.com/TheUnsocialEngineer/Antiland/tree/master/examples.

API Reference
--------------
.. toctree::
   :maxdepth: 1

   api
   /ext/commands/api.rst

Extensions
------------

This extension willhelp you during development when it comes to creating specific bot commands.

.. toctree::
  :maxdepth: 1

  /ext/commands/index.rst